diff -r 94186a96ca17 OPS
--- a/OPS	Tue Nov 24 21:45:58 2015 -0800
+++ b/OPS	Wed Nov 25 17:46:20 2015 +0100
@@ -112,10 +112,12 @@
 OP_MAIN_NEXT_NEW "jump to the next new message"
 OP_MAIN_NEXT_NEW_THEN_UNREAD "jump to the next new or unread message"
 OP_MAIN_NEXT_SUBTHREAD "jump to the next subthread"
+OP_MAIN_NEXT_TAGGED "jump to the next tagged message"
 OP_MAIN_NEXT_THREAD "jump to the next thread"
 OP_MAIN_NEXT_UNDELETED "move to the next undeleted message"
 OP_MAIN_NEXT_UNREAD "jump to the next unread message"
 OP_MAIN_PARENT_MESSAGE "jump to parent message in thread"
+OP_MAIN_PREV_TAGGED "jump to previous tagged message"
 OP_MAIN_PREV_THREAD "jump to previous thread"
 OP_MAIN_PREV_SUBTHREAD "jump to previous subthread"
 OP_MAIN_PREV_UNDELETED "move to the previous undeleted message"
diff -r 94186a96ca17 PATCHES
--- a/PATCHES	Tue Nov 24 21:45:58 2015 -0800
+++ b/PATCHES	Wed Nov 25 17:46:20 2015 +0100
@@ -0,0 +1,1 @@
+patch-1.5.24.aw.jumptagged.1
diff -r 94186a96ca17 curs_main.c
--- a/curs_main.c	Tue Nov 24 21:45:58 2015 -0800
+++ b/curs_main.c	Wed Nov 25 17:46:20 2015 +0100
@@ -1534,10 +1534,13 @@
       case OP_MAIN_PREV_UNREAD:
       case OP_MAIN_NEXT_NEW_THEN_UNREAD:
       case OP_MAIN_PREV_NEW_THEN_UNREAD:
+      case OP_MAIN_NEXT_TAGGED:
+      case OP_MAIN_PREV_TAGGED:
 
       {
 	int first_unread = -1;
 	int first_new    = -1;
+	int first_tagged = -1;
 
 	CHECK_MSGCOUNT;
         CHECK_VISIBLE;
@@ -1547,7 +1550,7 @@
 	for (j = 0; j != Context->vcount; j++)
 	{
 #define CURHDRi Context->hdrs[Context->v2r[i]]
-	  if (op == OP_MAIN_NEXT_NEW || op == OP_MAIN_NEXT_UNREAD || op == OP_MAIN_NEXT_NEW_THEN_UNREAD)
+	  if (op == OP_MAIN_NEXT_NEW || op == OP_MAIN_NEXT_UNREAD || op == OP_MAIN_NEXT_NEW_THEN_UNREAD || op == OP_MAIN_NEXT_TAGGED)
 	  {
 	    i++;
 	    if (i > Context->vcount - 1)
@@ -1581,6 +1584,11 @@
 	      first_new = i;
 	  }
 
+	  if (CURHDRi->tagged && first_tagged == -1) {
+	    first_tagged = i;
+	    break;
+	  }
+
 	  if ((op == OP_MAIN_NEXT_UNREAD || op == OP_MAIN_PREV_UNREAD) &&
 	      first_unread != -1)
 	    break;
@@ -1598,6 +1606,9 @@
 		  op == OP_MAIN_NEXT_NEW_THEN_UNREAD || op == OP_MAIN_PREV_NEW_THEN_UNREAD)
 		 && first_unread != -1)
 	  menu->current = first_unread;
+	else if ((op == OP_MAIN_NEXT_TAGGED || op == OP_MAIN_PREV_TAGGED)
+		 && first_tagged != -1)
+	  menu->current = first_tagged;
 
 	if (menu->current == -1)
 	{
@@ -1609,6 +1620,13 @@
             else
               mutt_error (_("No new messages."));
           }
+          else if (op == OP_MAIN_NEXT_TAGGED || op == OP_MAIN_PREV_TAGGED)
+	  {
+            if (Context->pattern)
+              mutt_error (_("No tagged messages in this limited view."));
+            else
+              mutt_error (_("No tagged messages."));
+	  }
           else
           {
             if (Context->pattern)
diff -r 94186a96ca17 functions.h
--- a/functions.h	Tue Nov 24 21:45:58 2015 -0800
+++ b/functions.h	Wed Nov 25 17:46:20 2015 +0100
@@ -159,6 +159,8 @@
   { "next-unread",		OP_MAIN_NEXT_UNREAD,		NULL },
   { "previous-unread",		OP_MAIN_PREV_UNREAD,		NULL },
   { "parent-message",		OP_MAIN_PARENT_MESSAGE,		"P" },
+  { "next-tagged",		OP_MAIN_NEXT_TAGGED,		NULL },
+  { "previous-tagged",		OP_MAIN_PREV_TAGGED,		NULL },
 
 
   { "extract-keys",		OP_EXTRACT_KEYS,		"\013" },
@@ -259,6 +261,8 @@
   { "previous-line",	OP_PREV_LINE,			NULL },
   { "bottom",		OP_PAGER_BOTTOM,		NULL },
   { "parent-message",	OP_MAIN_PARENT_MESSAGE,		"P" },
+  { "next-tagged",	OP_MAIN_NEXT_TAGGED,		NULL },
+  { "previous-tagged",	OP_MAIN_PREV_TAGGED,		NULL },
 
 
 
